#
# spec file for package blktests
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           blktests
Version:        0+20231006.1aeff01
Release:        1.1
Summary:        Linux kernel block layer testing framework
License:        GPL-2.0-or-later
URL:            https://github.com/osandov/blktests
Source:         %{name}-%{version}.tar.xz
BuildRequires:  gcc-c++
Requires:       fio
Requires:       gawk
Requires:       gcc
Requires:       make
Recommends:     blktrace
Recommends:     device-mapper
Recommends:     e2fsprogs
Recommends:     multipath-tools
Recommends:     nvme-cli
Recommends:     xfsprogs

%description
blktests is a test framework for the Linux kernel block layer and
storage stack. It is inspired by the xfstests filesystem testing
framework.

%prep
%setup -q

%build
make %{?_smp_mflags} V=1

%install
%make_install prefix="%{_prefix}/lib"

%files
%doc README.md
%license LICENSES/GPL-2.0 LICENSES/GPL-3.0
%{_prefix}/lib/blktests

%changelog
* Wed Oct 11 2023 pcervinka@suse.com
- Replace disabled mode in service file by manual mode
- Update to version 0+20231006.1aeff01:
  * nbd/004: avoid left connection
  * Change the default RDMA driver from rdma_rxe to siw
  * srp/015: Remove this test
  * tests/srp/rc: Reduce the number of channels
  * tests/srp/rc: Rework use_blk_mq()
  * tests/nvme/031: fix connecting faiure
  * block/002,scsi/007,zbd/003: remove options for shellcheck SC2119
  * nvme: introduce nvmet_target_{setup/cleanup} common code
  * nvme/{033,034,035,036,37}: drop port handle between passthru target setup and cleanup
  * nvme/{033,034,035,036}: use default subsysnqn variable directly
  * Revert "Do not suppress any shellcheck warnings"
  * nvme: remove "udevadm settle" after _nvme_connect_subsys
  * nvme/rc: fix nvme device readiness check after _nvme_connect_subsys
  * nvme: Add explicitly host to allow_host list
  * nvme/rc: Add helper for adding/removing to allow list
  * nvme: Use def_subsys_uuid variable
  * nvme/rc: Add common def_subsys_uuid define
  * nvme: Use def_file_path variable instead local variable
  * nvme/rc: Add common file_path name define
  * nvme/{041,042,043,044,045,048}: Remove local variable hostnqn and hostid
  * nvme: Use def_subsysnqn variable instead local variable
  * nvme/rc: Add common subsystem nqn define
  * nvme/043: Use hostnqn to generate DHCAP key
  * nvme: Reorganize test preamble code section
  * nvme/{003,004,005,013,046,049}: Group all variables declarations
  * block/004: reset zones of TEST_DEV before fio operation
  * README: clarify motivations to add new test cases
  * CONTRIBUTING, README: recommend patch post for contributions
  * README: describe what './new' script documents
  * new: don't mandate double square brackets
  * src/Makefile: fix static linking of miniublk
  * common/scsi_debug: Use _unload_module() instead of modprobe -r
  * _unload_module(): Report the failure reason once
  * block/005: require queue/scheduler sysfs attribute
  * block/004, zbd/{005,006}: call _test_dev_set_scheduler
  * common/rc: introduce _require_test_dev_sysfs
  * common/{rc,dm}: introduce functions to set scheduler of dm destinations
  * common/dm: add script file for device-mapper functions
  * check, common/rc: save sysfs attribute path
  * common/ublk: avoid modprobe failure for built-in ublk_drv
  * nvme/{041,042,043,044,045,048}: Use default hostnqn and hostid
  * nvme/rc: Avoid triggering host nvme-cli autoconnect
  * nvme/048: Check for queue count check directly
  * nvme/043: use a valid hostkey
  * zbd/009: skip have_good_mkfs_btrfs when mkfs.btrfs not avaiable
  * nvme/rc: specify hostnqn and hostid to nvme discover and connect
* Tue Jun 27 2023 petr@cervinka.net
- Update to version 0+20230615.154e652:
  * block/034: Test memory is released by null-blk driver with memory_backed=1
  * nvme/040: Free loop back resources
  * block/011: recover test target NVME device capacity
  * block/011: skip when mounted block devices are affected
  * common/rc: introduce _get_pci_from_dev_sysfs
  * nvmeof-mp: Remove nvmeof-mp tests
  * nvme/rc: remove _filter_discovery
  * nvme/{016,017}: use _check_genctr instead of _filter_discovery
  * nvme/rc: Cleanup fc resource before module unloading
  * nvme/rc: Cleanup fc ports in reverse order
  * tests: Add ublk tests
  * src/miniublk: add user recovery
  * srp/rc: Replace _have_module() with _have_driver()
  * nvme/{016,017}: Make the number iterations configurable
  * nvme/{002,030}: Move discovery generation counter code to rc
  * nvme/{045,047}: Calculate IO size for random fio jobs
  * nvme: Add minimal test image size requirement
  * nvme: Make test image size configurable
  * Documentation: Add info on nvme_trtype
  * nvme/{032,040}: Use runtime fio background jobs
  * common/xfs: Limit fio size job to fit into xfs fs
  * common/xfs: Make size argument optional for _xfs_run_fio_verify_io
  * nvme/{014/015}: Do not hard code device size for dd test
  * nvme/rc: Auto convert test device size info
  * block/{001,002,027}: allow to run with built-in scsi_debug and sd_mod
  * scsi/{004,005}: allow to run with built-in scsi_debug
  * common/scsi_debug: introduce _configure_scsi_debug
  * common/scsi_debug: factor out _setup_scsi_debug_vars
  * common/scsi_debug, tests/*: re-define _have_scsi_debug
  * common/rc: skip module file check if modules path does not exist
  * loop/009: add test for loop partition uvents
  * test/nvme: add missing _have_fio check for nvme/045
  * tests/dm: add dm test group and a test for self-map
  * common/rc: fix kernel version parse failure
  * block/{014,015,030}: don't require modular null_blk for fault-injection
  * src/Makefile: forward LDFLAGS to $(CC)
  * nvme/039: avoid failure by error message rate limit
  * nvme/049: add test for uring-passthrough
  * common,fio: helper for version check
  * nvme/048: test queue count changes on reconnect
  * nvme/rc: Add timeout argument parsing to _nvme_connect_subsys()
  * nvme/047: Test different queue types for fabrics transports
  * nvme/rc: Add parametric transport required check
  * nvme/rc: Add nr queue parser arguments to _nvme_connect_subsys()
  * nvme/rc: Parse optional arguments in _nvme_connect_subsys()
  * tests/block/013.out: remove the unused 013.out file
  * tests: add the missing +x mode
* Sun Apr  2 2023 bjorn.lie@gmail.com
- Update to version 0+20230302.676d42c:
  * src/Makefile: fix number sign handling in macro
  * block/033: add test to cover gendisk leak
  * src: add mini ublk source code
  * nvme/046: add test for unprivileged passthrough
  * check, common/rc: support normal user privilege
  * block/032: add test to cover umount one deleted disk
  * Update tests for discovery log page changes
  * tests/block/007: Rework I/O polling
- Use explicit commit id. Also exclude .gitignore files.
* Wed Dec  2 2020 pcervinka@suse.com
- Update to version 0+20201022.e10add0:
  * nvme/038: Test removal of un-enabled subsystem and ports
  * nvme/037: Add test which loops passthru connect and disconnect
  * nvme/036: Add test for testing reset command on nvme-passthru
  * nvme/035: Add test to verify passthru controller with a filesystem
  * nvme/034: Add test for passthru data verification
  * nvme/033: Simple test to create and connect to a passthru target
  * nvme: Add common helpers for passthru tests
  * nvme: Search for specific subsysnqn in _find_nvme_loop_dev
  * common/xfs: Create common helper to verify block device with xfs
  * common/xfs: Create common helper to check for XFS support
  * common/fio: Remove state file in common helper
  * zbd/003: Reset zones when the test device has max_active_zones limit
  * block/004: Provide max_active_zones to fio command
  * common/rc: Add _test_dev_max_active_zones() helper function
  * nvme: support rdma transport type
  * common: move module_unload to common
  * nvme: support nvme-tcp when runinng tests
  * tests/nvme: restrict tests to specific transports
  * nvme: make tests transport type agnostic
  * nvme: consolidate some nvme-cli utility functions
  * nvme: consolidate nvme requirements based on transport type
  * nvme/005: add the missing _have_program nvme
  * common/multipath-over-rdma: make block scheduler directory optional
  * zbd/002: Check write pointers only when zones have valid conditions
  * zbd/005: Enable zonemode=zbd when zone capacity is less than zone size
  * zbd/004: Check zone boundary writes using zones without zone capacity gap
  * zbd/002: Check validity of zone capacity
  * zbd/rc: Support zone capacity report by blkzone
  * Remove partition rereading tests for reverted fixes
  * tests/srp/rc: Separate login parameters with a comma
  * srp tests: Use _{init,exit}_scsi_debug() instead of duplicating these functions
  * common/multipath-over-rdma: Log mkfs output
  * srp, nvmeof-mp: Use no_path_retry instead of queue_if_no_path
  * tests/nvmeof-mp/rc: Make login failures easier to debug
  * block/012: add comment explaning second --setro
  * tests/srp/rc: Fix a shellcheck warning
  * tests: mark tests with CAN_BE_ZONED=1
  * common/cpuhotplug: fix ALL_CPUS
  * tests/srp/rc: Do not pass an empty string to dd
  * zbd/007: Add --force option to blkzone reset
  * Fix ./check: line 275: LAST_TEST_RUN["$key"]: unbound variable
  * Fix unquoted integer shellcheck errors
  * travis: update shellcheck URL
  * tests/srp/rc: Make the SRP tests pass against kernel v5.7
* Fri May  1 2020 Petr Cervinka <pcervinka@suse.com>
- Update to version 0+20200430.bff70b0:
  * Add $DESCRIPTION to the TEST_RUN
  * Fix unintentional skipping of tests
  * Add a test that triggers the blk_mq_realloc_hw_ctxs() error path
  * Introduce the function _configure_null_blk()
  * Use _{init,exit}_null_blk instead of open-coding these functions
  * Make _exit_null_blk remove all null_blk device instances
  * common/fio: do not use norandommap with verify
* Thu Apr  2 2020 Sebastian Chlad <sebastian.chlad@suse.com>
- Add blktrace to recommended as some tests require it
* Wed Mar 25 2020 pcervinka@suse.com
- Update to version 20200307.cd11d00:
  * Support skipping tests from test{,_device}()
  * Show last run for skipped tests
  * Skip tests based on SKIP_REASON, not return value
  * nbd/003: fix compiling error with gcc version 4.8.5
  * nbd/003:add mount and clear_sock test for nbd
  * nvme/018: Reword misleading error message
  * nvme/018: Ignore message generated by nvme read
  * tests/srp/015: Add a test that uses the SoftiWARP (siw) driver
  * common/multipath-over-rdma, tests/srp: Make it easy to use siw instead of rdma_rxe
  * common/multipath-over-rdma: Rename two functions
- Apply spec-cleaner
- Change version format in service file
- Add GPL-3.0 to license list
- Add README.md to doc section
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Sun Nov 25 2018 Jan Engelhardt <jengelh@inai.de>
- Move /var/lib/blktests to /usr/lib/blktests, packages don't
  deliver variadic data.
* Thu Nov 22 2018 Michael Moese <mmoese@suse.com>
- Fix package dependencies: nvmetcli is not needed, some packages
  can be missing (changed to Recommended:)
* Thu Nov 22 2018 Michael Moese <mmoese@suse.com>
- fix the %%files section: change %%{_sharedstatedir} to %%{_localstatedir}/lib
* Thu Nov 22 2018 Michael Moese <mmoese@suse.com>
- change %%{_sharedstatedir} to %%{_localstatedir}/lib
* Thu Nov 22 2018 Michael Moese <mmoese@suse.com>
- Correct the package category, System/Benchmarks is wrong
-> System/Benchmark
* Thu Nov 22 2018 Michael Moese <mmoese@suse.com>
  Move the installed files from /usr/share to /var/lib
* Thu Nov 22 2018 Michael Moese <mmoese@suse.com>
  move the installed files from /usr/local to /usr/share
* Wed Nov 21 2018 Michael Moese <mmoese@suse.com>
- clean the .spec
* Wed Nov 21 2018 Michael Moese <mmoese@suse.com>
- fix the group of the package
* Wed Nov 21 2018 Michael Moese <mmoese@suse.com>
- Add the blktests.spec file
* Wed Nov 21 2018 Michael Moese <mmoese@suse.com>
  Add new package for "blktests", the linux block layer testing framework
  from https://github.com/osandov/blktests
-
